@@ -7,7 +7,7 @@ from pyrfuniverse.envs.base_env import RFUniverseBaseEnv
 main_path = 'E:/rfuniverse/rfuniverse/Build/Grasp/RFUniverse_Data/StreamingAssets/grasp'
 point_path = os.path.join(main_path, 'point_list')
 survive_path = os.path.join(main_path, 'survive_list')
-index = 4
+index = 561
 with open(os.path.join(point_path, f'scene_{str(index).zfill(4)}.json'), 'r', encoding='utf8') as fp:
     point_data = json.load(fp)
 with open(os.path.join(survive_path, f'scene_{str(index).zfill(4)}.json'), 'r', encoding='utf8') as fp:
@@ -23,7 +23,7 @@ point = np.array(point).reshape(-1, 3)
 print(point.shape)
 color = point.copy()
 
-env2 = RFUniverseBaseEnv(executable_file='E:\\rfuniverse\\rfuniverse\\Build\\Grasp\\RFUniverse.exe',)
+env2 = RFUniverseBaseEnv(executable_file='@Editor',)
 env2.asset_channel.set_action(
     "InstanceObject",
     name='PointCloud',
